@@ -1,6 +1,7 @@
 import os
 import sys
 import traceback as tb
+from typing import Optional
 
 import requests
 
@@ -68,12 +69,12 @@ class BrowserBridge(DatabaseMixin, Bridge):
             raise ValueError(f"Unsupported browser type: {browser}")
 
     @traceback
-    def start(self, url=None):
+    def start(self, url=None, preferred_browser: Optional[str] = None):
         is_new_session = not self.is_running
         self.logger.debug("Is it a new session?: %s", is_new_session)
         if is_new_session:
             self.web_driver = WebDriver()
-            self.web_driver.start()
+            self.web_driver.start(preferred_browser=preferred_browser)
         if self.ctx.selected:
             locator_db = self.get_locators()
             self.logger.debug("Editing locator: %s", locator_db[self.ctx.selected])
