@@ -4,7 +4,7 @@ import os
 import signal
 import traceback
 from pathlib import Path, WindowsPath
-from typing import Dict, Union
+from typing import Dict, Optional, Union
 from urllib.parse import urlparse
 
 import psutil  # type: ignore
@@ -236,8 +236,12 @@ class WebDriver:
             self.selenium.execute_async_script, script, *args, **kwargs
         )
 
-    def _init_driver(self):  # noqa: C901
-        browsers = webdriver.get_browser_order()
+    def _init_driver(self, preferred_browser: Optional[str] = None):  # noqa: C901
+        browsers = (
+            [preferred_browser]
+            if preferred_browser is not None
+            else webdriver.get_browser_order()
+        )
         for browser in browsers:
             if browser == "Chrome":
                 kwargs = {"chrome_options": chrome_options()}
@@ -285,12 +289,12 @@ class WebDriver:
 
         return lambda val: self.selenium.find_elements(by=finder, value=val)
 
-    def start(self):
+    def start(self, preferred_browser: Optional[str] = None):
         if self.selenium:
             self.logger.warning("Webdriver already running")
 
         self.logger.debug("Starting browser")
-        self.selenium = self._init_driver()
+        self.selenium = self._init_driver(preferred_browser)
         self.logger.debug("Selenium driver: %s", self.selenium)
         self.selenium.set_script_timeout(self.SCRIPT_TIMEOUT)
 
